#!/bin/sh

pkg=perl
ver=5.8.8
major=5.8
release=-4
dir=`pwd`
shortver=`echo ${ver}${release} | sed 's/-.*//'`
timestamp=${dir}/pkg.timestamp
files=${dir}/pkg.files

# cleanup
mkdir -p old/
mv -f ${timestamp} ${files} ${files}.manpages ${files}.perl ${pkg}-${ver}${release}-src.tar.bz2 ${pkg}-${ver}${release}.tar.bz2 ${pkg}_manpages-${ver}${release}.tar.bz2 ${pkg}-${ver}${release}/ old/
mv -f /usr/share/doc/Cygwin/${pkg}-${shortver}.README old

## start
set -e
touch ${timestamp}
touch README

## install READMEs
/bin/install -m 644 README /usr/share/doc/Cygwin/${pkg}-${shortver}.README 
mkdir -p /usr/share/doc/${pkg}-${ver}
rm -rf /usr/share/doc/${pkg}-${ver}

# install prep: move away existing install
for d in /usr/lib/perl5 /usr/lib/perl5/site_perl /usr/lib/perl5/vendor_perl; do
  if test -d $d/tmp.$major -a -d $d/$major; then rm -rf $d/$major; fi
  if test -d $d/$major; then mv $d/$major $d/tmp.$major; fi
done

## build perl now
sh -x ${dir}/build.sh

## source package
rm -rf ${pkg}-${ver}${release}
mkdir ${pkg}-${ver}${release}
cp -p README pl-*.patch *.pl *.sh *.tar.gz ${pkg}-${ver}${release}
for i in `ls log.*`; do cp ${i} ${pkg}-${ver}${release}/${i}.rel; done
tar cjf ${pkg}-${ver}${release}-src.tar.bz2 ${pkg}-${ver}${release}

## binary package
## first the files
(cd / ; find usr/share/man -path usr/lib/perl5 -prune -o -type f -newer ${timestamp} -print) >${files}
#(cd / ; find usr/bin -path usr/lib/perl5 -prune -o -type f -newer ${timestamp} -print) | egrep -v "(5.8.8|5.9.5)$" >>${files}
# remove versioned scripts, keep versioned exe's (find prints .exe as .exe)
# remove usr/bin/ptar usr/bin/ptardiff, requires seperate site_perl Archive::Tar installation then
for packlist in $(find usr/lib/perl5 -name .packlist -type f -newer ${timestamp} -print); do
    cat $packlist | sed -e's, type=file,,' -e's, from=.*$,,' -e's,^/,,' | sort -u >>${files}
done
#echo usr/lib/perl5/5.8/auto/POSIX/SigAction >>${files}
echo usr/lib/perl5/${major} >>${files}
echo usr/lib/perl5/site_perl/${major} >>${files}
echo usr/lib/perl5/vendor_perl/${major} >>${files}
echo usr/share/doc/${pkg}-${ver} >>${files}
echo usr/share/doc/Cygwin/${pkg}-${ver}.README >>${files}
## separate manpages and remove builddirs from list
${dir}/separate.pl
## then pack it up
(cd /; tar -c -T ${files}.manpages) | bzip2 -9 >${pkg}_manpages-${ver}${release}.tar.bz2
(cd /; tar -c -T ${files}.perl) | bzip2 -9 >${pkg}-${ver}${release}.tar.bz2

# install fixup: move back existing install
for d in /usr/lib/perl5 /usr/lib/perl5/site_perl /usr/lib/perl5/vendor_perl; do
  if test -d $d/fresh.$major; then rm -rf $d/fresh.$major; fi
  mv $d/$major $d/fresh.$major
  if test -d $d/tmp.$major; then mv $d/tmp.$major $d/$major; fi
done
